export default {
    "message": "Cannot use keyword 'await' outside an async function",
    "column": 9,
    "index": 8,
    "lineNumber": 1
};
